<?php namespace MapGuesser\Repository;

use DateTime;
use Generator;
use SokoWeb\Database\Query\Select;
use MapGuesser\PersistentData\Model\User;
use MapGuesser\PersistentData\Model\UserPasswordResetter;

class UserPasswordResetterRepository
{
    public function getById(int $userConfirmationId): ?UserPasswordResetter
    {
        return \Container::$persistentDataManager->selectFromDbById($userConfirmationId, UserPasswordResetter::class);
    }

    public function getByToken(string $token): ?UserPasswordResetter
    {
        $select = new Select(\Container::$dbConnection);
        $select->where('token', '=', $token);

        return \Container::$persistentDataManager->selectFromDb($select, UserPasswordResetter::class);
    }

    public function getByUser(User $user): ?UserPasswordResetter
    {
        $select = new Select(\Container::$dbConnection);
        $select->where('user_id', '=', $user->getId());

        return \Container::$persistentDataManager->selectFromDb($select, UserPasswordResetter::class);
    }

    public function getAllExpired(): Generator
    {
        $select = new Select(\Container::$dbConnection);
        $select->where('expires', '<', (new DateTime())->format('Y-m-d H:i:s'));

        yield from \Container::$persistentDataManager->selectMultipleFromDb($select, UserPasswordResetter::class);
    }
}
